summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/ouroboros/CMakeLists.txt2
-rw-r--r--include/ouroboros/ipcp.h2
-rw-r--r--include/ouroboros/nsm.h (renamed from include/ouroboros/da.h)24
3 files changed, 17 insertions, 11 deletions
diff --git a/include/ouroboros/CMakeLists.txt b/include/ouroboros/CMakeLists.txt
index 9e9fc789..c5f65d49 100644
--- a/include/ouroboros/CMakeLists.txt
+++ b/include/ouroboros/CMakeLists.txt
@@ -4,13 +4,13 @@ configure_file(
set(HEADER_FILES
cdap.h
- da.h
dev.h
dif_config.h
errno.h
flow.h
instance_name.h
irm.h
+ nsm.h
qos.h
)
diff --git a/include/ouroboros/ipcp.h b/include/ouroboros/ipcp.h
index 89b9fa92..0d62bd59 100644
--- a/include/ouroboros/ipcp.h
+++ b/include/ouroboros/ipcp.h
@@ -46,7 +46,7 @@ int ipcp_unreg(pid_t pid,
size_t difs_size);
int ipcp_enroll(pid_t pid,
- char * member_name,
+ char * dif_name,
char * n_1_dif);
int ipcp_bootstrap(pid_t pid,
diff --git a/include/ouroboros/da.h b/include/ouroboros/nsm.h
index 406be7a8..69b1d9d2 100644
--- a/include/ouroboros/da.h
+++ b/include/ouroboros/nsm.h
@@ -1,7 +1,7 @@
/*
* Ouroboros - Copyright (C) 2016
*
- * The API to consult the DIF Allocator
+ * The API to instruct the global Namespace Manager
*
* Sander Vrijders <sander.vrijders@intec.ugent.be>
*
@@ -20,18 +20,24 @@
* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
-#ifndef OUROBOROS_DA_H
-#define OUROBOROS_DA_H
+#ifndef OUROBOROS_NSM_H
+#define OUROBOROS_NSM_H
#include <stdint.h>
#include <unistd.h>
-char * da_resolve_daf(char * daf_name);
+int nsm_reg(char * name,
+ char ** dafs,
+ size_t dafs_size);
+
+int nsm_unreg(char * name,
+ char ** dafs,
+ size_t dafs_size);
+
/*
* n_1_difs is an out parameter
* The amount of n_1_difs is returned
*/
-ssize_t da_resolve_dap(char * name,
- char ** n_1_difs);
-
+ssize_t nsm_resolve(char * name,
+ char ** dafs);
#endif
@@ -20,18 +20,24 @@
/*
- * n_1_difs is an out parameter
- * The amount of n_1_difs is returned
+ * dafs is an out parameter
+ * The amount of DAFs is returned
*/